[![Website shields.io](https://img.shields.io/website-up-down-green-red/http/shields.io.svg)](https://benjmy.github.io/pycathy_wrapper/)
[![made-with-sphinx-doc](https://img.shields.io/badge/Made%20with-Sphinx-1f425f.svg)](https://www.sphinx-doc.org/)
[![Upload Python Package](https://github.com/BenjMy/pycathy_wrapper/actions/workflows/python-publish.yml/badge.svg)](https://github.com/BenjMy/pycathy_wrapper/actions/workflows/python-publish.yml)

## Python package for hydrogeophysical data modeling

pyCATHY is a **Python wrapper for CATHY** (V1, and plant model version) allowing mesh creation, forward and inverse modeling, and simple output visualization of CATHY simulations

Check out the [**documentation**](https://benjmy.github.io/pycathy_wrapper/)

---

### Licence ###
This is free software: you can redistribute it and/or modify it under the terms of the BSD 3-clause License. A copy of this license is provided in LICENSE.md.

### References ###

- Camporese, M., Paniconi, C., Putti, M., Orlandini, S., 2010. Surface-subsurface flow modeling with path-based runoff routing, boundary condition-based coupling, and assimilation of multisource observation data: SURFACE-SUBSURFACE FLOW MODELING. Water Resour. Res. 46. https://doi.org/10.1029/2008WR007536



